/*
NOME: 0021_DENSTPO_EXPORTA_MOV_ESTOQUE.SQL

DESCRIO: Procedimento para exportao das movimentaes de Estoque.

CRIAO: 26/08/2008 - Fabrcio Marcelo da Silva

@C:\Web_505\Xdb\Src\Cli\DEN\Sql\0021_DENSTPO_EXPORTA_MOV_ESTOQUE.SQL

RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
*/

CREATE OR REPLACE PROCEDURE EXPORTA_MOV_ESTOQUE(
     P_DTINICIAL IN LANCTOESTOQ.DTLANCESTQ%TYPE,
     P_DTFINAL   IN LANCTOESTOQ.DTLANCESTQ%TYPE)
AS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
      INTO V_DTGRV, V_HRGRV
      FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;
   /* Verificao dos lanamentos de estoque (retirada) */
   FOR C_MOVESTO IN (SELECT L.CDFILIAL,
                            L.NRLANCESTQ,
                            SUBSTR(F.CDGRUPFILI,7,2) AS EMPRESA,
                            SUBSTR(F.CDGRUPFILI,9,2) AS FILIAL,
                            L.IDTPLANCTO,
                            L.CDFILIMOVI,
                            P.CDPRODINTE,
                            TO_CHAR(L.DTLANCESTQ, 'DDMMYYYY') AS DTLANCESTQ,
                            SUM(I.QTLANCTOEST) AS QTDEMOVI,
                            SUM(I.VRTOTLANCTO) AS VALRMOVI
                       FROM LANCTOESTOQ L, ITLANCTOEST I, PRODUTO P,
                            (SELECT CDFILIAL, MIN(CDGRUPFILI) AS CDGRUPFILI
                               FROM FILGRUPFILI
                               GROUP BY CDFILIAL) F
                      WHERE (L.DTLANCESTQ BETWEEN P_DTINICIAL AND P_DTFINAL)
                        AND (L.IDTPLANCTO = '3')

                        AND (I.CDFILIAL   = L.CDFILIAL)
                        AND (I.NRLANCESTQ = L.NRLANCESTQ)

                        AND (I.CDPRODUTO = P.CDPRODUTO)

                        AND (F.CDFILIAL = L.CDFILIMOVI)
                      GROUP BY L.CDFILIAL,
                               L.NRLANCESTQ,
                               SUBSTR(F.CDGRUPFILI,7,2),
                               SUBSTR(F.CDGRUPFILI,9,2),
                               L.IDTPLANCTO,
                               L.CDFILIMOVI,
                               P.CDPRODINTE,
                               TO_CHAR(L.DTLANCESTQ, 'DDMMYYYY'))
   LOOP
      UPDATE USR_ZWG
      SET WG_EMPRESA = C_MOVESTO.EMPRESA,
          WG_FILIAL  = C_MOVESTO.FILIAL,
          WG_TM      = C_MOVESTO.IDTPLANCTO,
          WG_COD     = SUBSTR(C_MOVESTO.CDPRODINTE,1,15),
          WG_LOCAL   = NULL,
          WG_QUANT   = C_MOVESTO.QTDEMOVI,
          WG_EMISSAO = C_MOVESTO.DTLANCESTQ,
          WG_CC      = C_MOVESTO.CDFILIMOVI,
          WG_CUSTO   = C_MOVESTO.VALRMOVI,
          WG_DOC     = '',
          WG_USUARIO = NULL,
          WG_CONTA   = NULL,
          WG_ITEMCTA = NULL,
          WG_CLVL    = NULL,
          WG_LOTECTL = NULL,
          WG_NUMLOTE = NULL,
          WG_DTVALID = NULL,
          WG_TPEDI   = '2',
          WG_DTGRV   = V_DTGRV,
          WG_HRGRV   = V_HRGRV
      WHERE WG_CDFILIAL = C_MOVESTO.CDFILIAL
        AND WG_NRLANCESTQ = C_MOVESTO.NRLANCESTQ;

      IF SQL%ROWCOUNT = 0 THEN
         /* Insere movimentao de estoque */
         INSERT INTO USR_ZWG
            (WG_CDFILIAL, WG_NRLANCESTQ, WG_EMPRESA, WG_FILIAL, WG_TM, WG_COD, WG_LOCAL, WG_QUANT,
             WG_EMISSAO, WG_CC, WG_CUSTO, WG_DOC, WG_USUARIO, WG_CONTA, WG_ITEMCTA, WG_CLVL,
             WG_LOTECTL, WG_NUMLOTE, WG_DTVALID, WG_TPEDI, WG_DTGRV, WG_HRGRV)
         VALUES
            (C_MOVESTO.CDFILIAL, C_MOVESTO.NRLANCESTQ, C_MOVESTO.EMPRESA, C_MOVESTO.FILIAL, C_MOVESTO.IDTPLANCTO, SUBSTR(C_MOVESTO.CDPRODINTE,1,15), NULL, C_MOVESTO.QTDEMOVI,
             C_MOVESTO.DTLANCESTQ, C_MOVESTO.CDFILIMOVI, C_MOVESTO.VALRMOVI, '', NULL, NULL, NULL, NULL,
             NULL, NULL, NULL, '1', V_DTGRV, V_HRGRV);
      END IF;


      /* Inclui a data de exportao para os documentos exportados*/
--      UPDATE NOTAFISCAL
--      SET DTEXPORTACAO = V_DTGRV
--      WHERE CDFILIAL   = C_MOVESTO.CDFILIAL    AND
--            NRLANCTONF = C_MOVESTO.NRLANCTONF;
   END LOOP;
   COMMIT;
END;
/
